pub enum ItemAlignment {
None,
Fill,
Center,
Left,
Right,
Top,
Bottom,
}Variants
None
No constraints are added, items can be aligned individually
Fill
Item width/height matched layout parent
Center
Items centered within layout parent width/height
Left
For a vertical layout, align items to the parent’s left bound. Do not use in a horizontal layout
Right
For a vertical layout, align items to the parent’s right bound. Do not use in a horizontal layout
Top
For a horizontal layout, align items to the parent’s top bound. Do not use in a vertical layout
Bottom
For a horizontal layout, align items to the parent’s bottom bound. Do not use in a vertical layout