pub enum Spacing {
Around,
Between,
End,
Start,
}Variants
Around
Equal spacing before, after and between all elements
Between
Equal spacing between elements, with no extra space on the ends
End
Elements packed together at the start, leaving space at the end
Start
Elements packed together at the end, leaving space at the start