pub struct LinearLayoutSettings {
pub orientation: Orientation,
pub spacing: Spacing,
pub item_align: ItemAlignment,
pub fill_equal: bool,
pub padding: f32,
}Fields
orientation: OrientationHorizontal or vertical orientation of the current layout
spacing: SpacingSpecifies the extra space between elements along the primary axis
item_align: ItemAlignmentSpecifies alignment of items perpendicular to the primary axis
fill_equal: boolConstrain items to have equal size along primary axis, and fill container
padding: f32Minimum spacing between items
Implementations
Sourceimpl LinearLayoutSettings
impl LinearLayoutSettings
Sourcepub fn new(orientation: Orientation) -> Self
pub fn new(orientation: Orientation) -> Self
Creates a default LinearLayoutSettings, aligned to the
end of the parent container